summaryrefslogtreecommitdiffstats
path: root/lib/kross/main/mainmodule.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/main/mainmodule.h')
-rw-r--r--lib/kross/main/mainmodule.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kross/main/mainmodule.h b/lib/kross/main/mainmodule.h
index 96abd06d..06a4836d 100644
--- a/lib/kross/main/mainmodule.h
+++ b/lib/kross/main/mainmodule.h
@@ -151,19 +151,19 @@ namespace Kross { namespace Api {
QtObject::Ptr addTQObject(TQObject* object, const TQString& name = TQString());
/**
* Add a \a KAction to the eventcollection. The
* KAction will be wrapped by a \a EventAction
* and will be added to this collection.
*
* \param name name to identify the \a action by
* \param action the KAction instance that should
* be added to this \a MainModule
* \return the newly added \a EventAction instance
* which is now a child of this \a MainModule
*
* \todo check \a name dox.
*/
- EventAction::Ptr addKAction(KAction* action, const TQString& name = TQString());
+ EventAction::Ptr addTDEAction(TDEAction* action, const TQString& name = TQString());
//typedef TQValueList<Callable::Ptr> EventList;
//EventList getEvents();
@@ -151,19 +151,19 @@ namespace Kross { namespace Api {
QtObject::Ptr addTQObject(TQObject* object, const TQString& name = TQString());
/**
- * Add a \a KAction to the eventcollection. The
- * KAction will be wrapped by a \a EventAction
+ * Add a \a TDEAction to the eventcollection. The
+ * TDEAction will be wrapped by a \a EventAction
* and will be added to this collection.
*
@@ -151,19 +151,19 @@ namespace Kross { namespace Api {
*
* \param name name to identify the \a action by
- * \param action the KAction instance that should
+ * \param action the TDEAction instance that should
* be added to this \a MainModule
* \return the newly added \a EventAction instance